@@ -59,16 +59,18 @@ class ExecuteResult:
 
 
 class Executor:
+    def __init__(self, verbose=True, exit_hook=None):
+        """_summary_
 
-    verbose = True
-    """是否输出详细执行信息
-    """
-    previous_cwd: str = None
-    """记录执行前的工作目录
-    """
-
-    def __init__(self, verbose=True):
+        Args:
+            verbose (bool, optional): 是否输出详细执行信息. Defaults to True.
+            exit_hook (_type_, optional): 记录执行前的工作目录. Defaults to None.
+        """
         self.verbose = verbose
+        self.previous_cwd: str = None
+        if not callable(exit_hook):
+            exit_hook = None
+        self.exit_hook = exit_hook
 
     def format_args(self, args):
         """统一转换命令参数
@@ -99,7 +101,10 @@ class Executor:
         logger.error(f'\nCommand failed: {result.cmd_line}\n'
                      f'code: {result.code}\n'
                      f'message: {error_message}', True)
-        sys.exit(exit_code)
+        if self.exit_hook is not None:
+            self.exit_hook(exit_code)
+        else:
+            sys.exit(exit_code)
 
     def path_to_temp_dir(self):
         """
@@ -219,8 +224,6 @@ class Executor:
         self.__change_cwd(work_dir)
 
         if self.verbose:
-            logger.LOG_INDENT
-            logger.LOG_INDENT += 1
             via = 'Shell' if shell else 'Program'
             logger.info(f'=> Exec[{via}]: {joined_args}', True)
             if work_dir is not None:
@@ -264,8 +267,6 @@ class Executor:
 
         if not ignore_error and result.code != 0:
             self.common_error_out(result)
-        if self.verbose:
-            logger.LOG_INDENT -= 1
         self.__restore_cwd()
 
         return result
@@ -417,7 +418,8 @@ class Executor:
             with open(unity_path_config_yaml, 'r') as f:
                 config_yaml = yaml.safe_load(f)
             if full_version_str is None:
-                return config_yaml[config_yaml.keys()[0]]
+                for key in config_yaml.keys():
+                    return config_yaml[key]
             if full_version_str in config_yaml:
                 return config_yaml[full_version_str]
         # 先尝试直接从环境变量中获取
@@ -534,13 +536,9 @@ class Executor:
 
     @deprecated(version='0.2.9', reason="You should always use importlib and sys.modules for python module execution.")
     def execute_module(self, module, *module_parameters):
-        logger.LOG_INDENT += 1
-
         module_name = module.__name__
         logger.info('=> Module: {}'.format(module_name), True)
         start_time = time.time()
         result = module.main(*module_parameters)
         logger.info('<= Finished: {0} {1:.2f} seconds '.format(module_name, time.time() - start_time), True)
-
-        logger.LOG_INDENT -= 1
         return result
